# Packages and rsyslog fragmens required for TLS/RELP support

class base::syslog::tls_support {

  package {
    'rsyslog-gnutls': ensure => installed;
    'rsyslog-relp':   ensure => installed;
  }
  base::syslog::fragment { '05-modules-relp.conf':
    ensure  => present,
    source  => 'puppet:///modules/base/syslog/etc/rsyslog.d/05-modules-relp.conf';
  }

  # Install the CA certificate for the syslog server
  $ca_cert_file = "/etc/ssl/certs/${syslog_server}.ca.pem"
  file { $ca_cert_file:
    ensure => present,
    source => "puppet:///modules/cert-files/${syslog_server}.ca.pem",
    notify => Service['syslog'],
  }
  apache::cert::hash { "${syslog_server}.ca.pem":
    ensure  => present,
    require => File["/etc/ssl/certs/${syslog_server}.ca.pem"],
  }
}
